#ifndef FGGL_GFX_ECS_H
#define FGGL_GFX_ECS_H

#include <fggl/ecs2/ecs.hpp>
#include <fggl/math/types.hpp>

#include <GL/gl.h>

namespace fggl::components {

	struct GfxToken {
		GLuint vao;
		GLuint buffs[2];
		GLuint idxOffset;
		GLuint idxSize;
		GLuint pipeline;
	};

	struct GfxMat {
		math::mat4 model;
		math::mat4 view;
		math::mat4 proj;
	};

	struct Camera {
		math::vec3 target = math::vec3(0.0f, 0.0f, 0.0f);
		float aspectRatio = 1280.0f / 720.0f;
		float fov = glm::radians(45.0f);
		float nearPlane = 0.1f;
		float farPlane = 100.0f;
	};

	class Gfx {
		public:
			inline Gfx(ecs2::impl::world& world) {
				world.module<Gfx>("gfx");
				world.component<GfxToken>("token");
				world.component<Camera>("camera");
				world.component<GfxMat>("mat");
			}
	};
};

#endif
